@@ -1,7 +1,7 @@
-boxed.labels<-function(x,y,labels,col="white",border=TRUE,xpad=0.6,ypad=0.6,...) {
+boxed.labels<-function(x,y,labels,bg="white",border=TRUE,xpad=0.6,ypad=0.6,...) {
  widths<-strwidth(labels)
  heights<-strheight(labels)
  rect(x-widths*xpad,y-heights*ypad,x+widths*xpad,y+heights*ypad,
-  col=col,border=border)
+  col=bg,border=border)
  text(x,y,labels,...)
 }
